asr.test.test\_setup\_decorate
==============================

.. automodule:: asr.test.test_setup_decorate

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_setup_decorate_si
   
   

   
   
   

   
   
   